Chromedriver
============

This package is chromedriver downloads helper, it's downloads chromedriver from http://chromedriver.storage.googleapis.com/index.html on installation step.
To use it just add chromedriver into your install_requires and than where you need a path to chromedriver binrry:

.. code::

    from chromedriver import CHROMEDRV_PATH


.. warning::

    This package may containe bugs and works only under linux.

Also on import this package patches system PATH to have directory with 'chromedriver'.
